

These base classes are used internally to build PDFs and can also be
used to implement custom PDFs.

They offer more or less support and freedom.

.. autosummary::
    :toctree: _generated/custom_base

    zfit.pdf.ZPDF
    zfit.pdf.SimplePDF
    zfit.pdf.SimpleFunctorPDF
    zfit.pdf.WrapDistribution
    zfit.pdf.BasePDF
    zfit.pdf.BaseFunctor
